rad2 <- 
function(ref=NULL, sep=";", dec=",", ...) {
         
  Read(ref, sep=";", dec=",", ...)

}
